@@ -202,6 +202,7 @@ pub trait MutStats {
 }
 
 /// Vector Algebra on two vectors (represented here as generic slices).
+/// Also included are scalar operations on the `self` vector.
 pub trait Vecg<T,U> { 
     /// Scalar addition to vector
     fn sadd(self, s:U) -> Vec<f64>;
@@ -249,7 +250,8 @@ pub trait Vecg<T,U> {
     /// Spearman rho correlation.
     fn spearmancorr(self, v:&[U]) -> f64;   
 }
-
+/// Vector algebra: methods operaing on one vector of generic end type
+/// and the second argument, which is a scalar or vector of f64 end type.
 pub trait Vecf64<_T> {
     /// Scalar multiplication by f64
     fn smultf64(self, s:f64) -> Vec<f64>;
@@ -343,6 +345,8 @@ pub trait VecVecu8 {
     fn wcovar(self, ws:&[u8], m:&[f64]) -> Vec<f64>;
 }
 
+/// Methods applicable to a single argument: a vector of vectors of generic end type.
+/// Operations on a set of multidimensional vectors.
 pub trait VecVec<T> {
     /// Arithmetic Centre = euclidian mean of a set of points
     fn acentroid(self) -> Vec<f64>;
@@ -377,16 +381,17 @@ pub trait VecVec<T> {
     /// Medoid and Outlier as defined by eccentricities.
     fn emedoid(self, eps: f64) -> MinMax<f64> where Vec<f64>:FromIterator<f64>;
     /// Returns ( gm, sorted eccentricities magnitudes )
-    fn sortedeccs(self, ascending:bool, eps:f64) -> ( Vec<f64>,Vec<f64> );
-    /// Error vector for (usually non-member) point p
-    fn errorvf64(self, p:&[f64]) -> Vec<f64>;
+    fn sortedeccs(self, ascending:bool, eps:f64) -> ( Vec<f64>,Vec<f64> ); 
     /// Improved Weizsfeld's Algorithm for geometric median, to accuracy eps
     // fn nmedian(self, eps: f64) -> Vec<f64>;
     /// New algorithm for geometric median, to accuracy eps    
-    fn gmedian(self, eps: f64) -> Vec<f64>; 
+    fn gmedian(self, eps: f64) -> Vec<f64>;
+    /// Secant method geometric median
+    fn smedian(self, eps: f64) -> Vec<f64>;   
 }
 
-/// Methods applicable to vector of vectors of generic end type
+/// Methods applicable to vector of vectors of generic end type and one argument
+/// of a similar kind.
 pub trait VecVecg<T,U> { 
     /// Weighted Arithmetic Centre = weighted euclidian mean of a set of points
     fn wacentroid(self,ws: &[U]) -> Vec<f64>;
@@ -404,12 +409,14 @@ pub trait VecVecg<T,U> {
     fn wsortedeccs(self, ws: &[U], eps:f64) -> ( Vec<f64>,Vec<f64>,Vec<f64> ); 
     /// Sorted cosines magnitudes and cpdf, needs central median
     fn wsortedcos(self, medmed: &[U], med: &[U], ws: &[U]) -> ( Vec<f64>,Vec<f64> ); 
-    /// Error vector, i.e. unscaled eccentricity vector
-    fn errorv(self, p:&[U]) -> Vec<f64>;
     /// Estimated weighted gm computed at a non member point
     fn wnxnonmember(self, ws:&[U], p:&[f64]) -> Vec<f64>; 
-    /// The weighted geometric median to accuracy eps (new secant algorithm)
+    /// Estimated weighted eccentricity for a non-member point 
+    fn weccnonmember(self, ws:&[U], p:&[f64]) -> Vec<f64>;
+    /// The weighted geometric median to accuracy eps 
     fn wgmedian(self, ws: &[U], eps: f64) -> Vec<f64>; 
+    /// The weighted geometric median to accuracy eps
+    fn wsmedian(self, ws: &[U], eps: f64) -> Vec<f64>; 
     /// Flattened lower triangular part of a covariance matrix of a Vec of f64 vectors.
     fn covar(self, med:&[U]) -> Vec<f64>; 
     /// Flattened lower triangular part of a comediance matrix of a Vec of f64 vectors.
